@@ -29,11 +29,11 @@ public:
     bool m_calendarOwnership = true; // If false it's not ours.
 
     void deleteTodos();
-    Q_REQUIRED_RESULT bool treeIsDeletable(const KCalendarCore::Todo::Ptr &todo);
+    [[nodiscard]] bool treeIsDeletable(const KCalendarCore::Todo::Ptr &todo);
 
 public Q_SLOTS:
     void onCalendarLoaded(bool success, const QString &message);
-    void onItemsDeleted(int changeId, const QVector<Akonadi::Item::Id> &deletedItems, Akonadi::IncidenceChanger::ResultCode, const QString &message);
+    void onItemsDeleted(int changeId, const QList<Akonadi::Item::Id> &deletedItems, Akonadi::IncidenceChanger::ResultCode, const QString &message);
 
 private:
     TodoPurger *const q;
